==> hermes-5.6.0.33.tar.gz: hermes-5.6.0.33/app/controllers/hermes/api/dmo/statuses_controller.rb <==
module Hermes
  module Api
    module Dmo
      class StatusesController < Hermes::Api::Dmo::ApplicationController

       # before_action :set_instance, only: [:update, :destroy, :show]
        MAX_PICTURE_NUMBER = 5
        MUTATE_PARAMS = %i[
          status_label
          motive
          title
          object_id
          performer_id
        ]

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
          ids
          reference_model_name
          status_label
          motive
          title
          object_id
          performer_id
          closed_by
          closed_at
          closing
          applicant
          housing_request
          housing_offer
          housing_application
          entity
          lessor
        ]

        REGEX_PARAMS = %w[
          motive
          title
        ]
        
        def mutate_params
          MUTATE_PARAMS
        end 

        def current_user_is_admin
          !(current_user_roles & ['Administrator', 'superadministrator']).empty?
        end 


        def index
          return render_json_error(:unauthorized, :not_admin) unless current_user_is_admin
          
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS

          paginate(
            index_aggregation(no_acl: true),
            each_serializer: @serializer,
            **@options
          )
        end

        def show
          return render_json_error(:unauthorized, :not_admin) unless current_user_is_admin
          super
        end 

        def applications_history
          return render_json_error(:unauthorized, :not_demandeur) unless current_user_roles.include?('demandeur')

          matching = {
            reference_model_name: 'Hermes::HousingApplication',
            'housing_application.user_id' => @user.id
          }
          if params[:start_date].present? || params[:end_date].present?
            date_query = {}.tap do |h|
              h[:$gte] = Time.parse(params[:start_date]).beginning_of_day if params[:start_date].present?
              h[:$lte] = Time.parse(params[:end_date]).end_of_day if params[:end_date].present?
            end
            matching.merge!(updated_at: date_query)
          end

          aggregation = @model.collection.aggregate([
            { '$lookup' => { from: 'hermes_housing_applications', localField: 'housing_application_id', foreignField: '_id', as: 'housing_application' }},
            { '$match' => matching }
          ])

          paginate(
            aggregation,
            each_serializer: @serializer,
          )
        end
      end
    end
  end
end

==> hermes-6.0.2.29.tar.gz: hermes-6.0.2.29/app/controllers/hermes/api/dmo/statuses_controller.rb <==
module Hermes
  module Api
    module Dmo
      class StatusesController < Hermes::Api::Dmo::ApplicationController

       # before_action :set_instance, only: [:update, :destroy, :show]
        MAX_PICTURE_NUMBER = 5

        class << self
          def mutate_params
            {
              status_label: {type: 'String'},
              motive: {type: 'String'},
              title: {type: 'String'},
              object_id: {type: 'String'},
              performer_id: {type: 'String'},
            }
          end 
      
          def acceptable_params
            {
              reference_model_name: {type: 'String'},
              closed_by: {type: 'String'},
              closed_at: {type: 'DateTime'},
              closing: {type: 'String'},
            }.merge(self.mutate_params).merge(super)
          end 
      
          def valid_operators
            %w[$in $nin $ne $gt $gte $lt $lte $regex]
          end
      
          def regex_params
            {
              motive: {type: 'String'},
              title: {type: 'String'},
            }
          end 
        end
      

        def current_user_is_admin
          !(current_user_roles & ['Administrator', 'superadministrateur']).empty?
        end 


        def index
          return render_json_error(:unauthorized, :not_admin) unless current_user_is_admin
          
          acceptable_params *self.class.acceptable_params.keys
          regex_params *self.class.regex_params.keys
          valid_operators *self.class.valid_operators

          paginate(
            index_aggregation(no_acl: true),
            each_serializer: @serializer,
            **@options
          )
        end

        def show
          return render_json_error(:unauthorized, :not_admin) unless current_user_is_admin
          super
        end 

        def applications_history
          return render_json_error(:unauthorized, :not_demandeur) unless current_user_roles.include?('demandeur')

          matching = {
            reference_model_name: 'Hermes::HousingApplication',
            'housing_application.user_id' => @user.id
          }
          if params[:start_date].present? || params[:end_date].present?
            date_query = {}.tap do |h|
              h[:$gte] = Time.parse(params[:start_date]).beginning_of_day if params[:start_date].present?
              h[:$lte] = Time.parse(params[:end_date]).end_of_day if params[:end_date].present?
            end
            matching.merge!(updated_at: date_query)
          end

          aggregation = @model.collection.aggregate([
            { '$lookup' => { from: 'hermes_housing_applications', localField: 'housing_application_id', foreignField: '_id', as: 'housing_application' }},
            { '$match' => matching }
          ])

          paginate(
            aggregation,
            each_serializer: @serializer,
          )
        end
      end
    end
  end
end
